Module requests

Module requests 

Include several request builders to interact with the Extension API.

Structs

ErrorRequest
Payload to send error information to the Extensions API.

Functions

exit_error
Create a new exit error request to send to the Extensions API
init_error
Create a new init error request to send to the Extensions API