Module field

Module field 

Available on crate feature tracing only.
Utilities for working with fields and field visitors.

Modules

debug
MakeVisitor wrappers for working with fmt::Debug fields.
delimited
A MakeVisitor wrapper that separates formatted fields with a delimiter.
display
MakeVisitor wrappers for working with fmt::Display fields.

Traits

MakeExt
Extension trait providing MakeVisitor combinators.
MakeOutput
Extension trait implemented for all MakeVisitor implementations that produce a visitor implementing VisitOutput.
MakeVisitor
Creates new visitors.
RecordFields
Extension trait implemented by types which can be recorded by a visitor.
Visit
Visits typed values.
VisitFmt
Extension trait implemented by visitors to indicate that they write to a fmt::Write instance, and allow access to that writer.
VisitOutput
A visitor that produces output once it has visited a set of fields.
VisitWritestd
Extension trait implemented by visitors to indicate that they write to an io::Write instance, and allow access to that writer.