Module time

Module time 

Available on crate features fmt and std and tracing only.
Formatters for event timestamps.

Structs

SystemTime
Retrieve and print the current wall-clock time.
Uptime
Retrieve and print the relative elapsed wall-clock time since an epoch.

Traits

FormatTime
A type that can measure and format the current time.

Functions

time
Returns a new SystemTime timestamp provider.
uptime
Returns a new Uptime timestamp provider.